"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MongoClientFactory = void 0;
const tslib_1 = require("tslib");
const inject_1 = require("@furystack/inject");
const mongodb_1 = require("mongodb");
/**
 * Factory for instantiating MongoDb clients
 */
let MongoClientFactory = class MongoClientFactory {
    constructor() {
        this.connections = new Map();
    }
    async dispose() {
        await Promise.all([...this.connections.values()].map((c) => c.close(true)));
        this.connections.clear();
    }
    async getClientFor(url, options) {
        const existing = this.connections.get(url);
        if (existing) {
            return existing;
        }
        const client = new mongodb_1.MongoClient(url, options);
        this.connections.set(url, client);
        return client;
    }
};
MongoClientFactory = tslib_1.__decorate([
    (0, inject_1.Injectable)({ lifetime: 'singleton' })
], MongoClientFactory);
exports.MongoClientFactory = MongoClientFactory;
//# sourceMappingURL=mongo-client-factory.js.map